edc-lab-panel
-------------

A collection of common lab panels used in edc deployments

* FBC
* RFT
* LFT
* LIPIDS
* HbA1c
* Glucose

Also included are normal and graded ranges for the test results in these panels.